@@ -1,24 +1,5 @@
-/*
- * main.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of dot_mcp, a mcp for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * dot_mcp is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * dot_mcp is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with dot_mcp; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
@@ -230,6 +211,7 @@ static void* del_app(int oid)
 			focus = NULL;
 		}
 		free(a);
+		a = NULL;
 		place_apps();
 	}
 	return a;
@@ -273,11 +255,12 @@ static int mcp_object(struct s3d_evt *hrmz)
 		a = (struct app*)malloc(sizeof(struct app));
 		a->oid = mo->object;
 		a->r = mo->r;
-		strncpy(a->name, mo->name, 256);
+		strncpy(a->name, mo->name, sizeof(a->name));
+		a->name[sizeof(a->name) - 1] = '\0';
 		a->init = 0;
+		printf("..%s\n", a->name);
 		add_app(a);
 		place_apps();
-		printf("..%s\n", a->name);
 	} else {
 		/*  printf("updating app %d\n",a->oid);*/
 		a->trans_x = mo->trans_x;
