@@ -1,24 +1,5 @@
-/*
- * client.c
- *
- * Copyright (C) 2006-2011  Marek Lindner <lindner_marek@yahoo.de>
- *
- * This file is part of kism3d, an 802.11 visualizer for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * kism3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * kism3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with olsrs3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2006-2015  Marek Lindner <mareklindner@neomailbox.ch>
  */
 
 
@@ -50,7 +31,8 @@ struct wlan_client *get_wlan_client(char *mac) {
 
 	INIT_LIST_HEAD(&wlan_client->list);
 
-	strncpy(wlan_client->mac, mac, 18);
+	strncpy(wlan_client->mac, mac, sizeof(wlan_client->mac));
+	wlan_client->mac[sizeof(wlan_client->mac) - 1] = '\0';
 	wlan_client->wlan_network = NULL;
 
 	wlan_client->props_changed = 1;
