@@ -1,24 +1,5 @@
-/*
- * network.c
- *
- * Copyright (C) 2006-2011  Marek Lindner <lindner_marek@yahoo.de>
- *
- * This file is part of kism3d, an 802.11 visualizer for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * kism3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * kism3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with olsrs3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2006-2015  Marek Lindner <mareklindner@neomailbox.ch>
  */
 
 
@@ -45,7 +26,8 @@ struct wlan_network *get_wlan_network(char *bssid) {
 
 	INIT_LIST_HEAD(&wlan_network->list);
 
-	strncpy(wlan_network->bssid, bssid, 18);
+	strncpy(wlan_network->bssid, bssid, sizeof(wlan_network->bssid));
+	wlan_network->bssid[sizeof(wlan_network->bssid) - 1] = '\0';
 
 	wlan_network->type = -1;
 	wlan_network->chan = -1;
