@@ -1,31 +1,14 @@
-/*
- * meshs3d.h
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- * Copyright (C) 2004-2011  Marek Lindner <lindner_marek@yahoo.de>
- * Copyright (C) 2004-2011  Andreas Langer <andreas_lbg@gmx.de>
- *
- * This file is part of meshs3d, an olsr/batman topology visualizer for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * olsrs3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * olsrs3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with olsrs3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+/* SPDX-License-Identifier: GPL-2.0-or-later */
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
+ * SPDX-FileCopyrightText: 2004-2015  Marek Lindner <mareklindner@neomailbox.ch>
+ * SPDX-FileCopyrightText: 2004-2015  Andreas Langer <an.langer@gmx.de>
  */
 
 #ifndef _MESHS3D_H_
 #define _MESHS3D_H_
 
+#include <stdint.h>
+
 #define max(x,y) ((x)>(y)?(x):(y))
 #define min(x,y) ((x)<(y)?(x):(y))
 #define max_id(x,y) (id_comp(&(x), &(y)) > 0?(x):(y))
@@ -77,7 +60,7 @@ struct olsr_neigh_list {
 struct node {
 	struct node_id address;
 	char name_string[NAMEMAX];  /* host ip */
-	int node_type;     /* normal = 0, internet gateway = 1, via hna announced network = 2 */
+	int node_type;     /* normal = 0, internet gateway = 1, via tt announced network = 2 */
 	int node_type_modified;   /* node_type modified flag */
 	int last_seen;     /* last seen counter */
 	int visible;     /* is this node visible or vanished */
@@ -92,7 +75,7 @@ struct glob {
 	int debug;
 	int obj_node_normal;
 	int obj_node_inet;
-	int obj_node_hna;
+	int obj_node_tt;
 	int obj_btn_close;
 	int obj_s3d_url;
 	int obj_zero_point;
