@@ -1,28 +1,10 @@
-/*
- * dialog.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dfm, a s3d file manager.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dfm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dfm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dfm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
 #include "s3dfm.h"
+#include <s3d.h>
 #include <s3d_keysym.h>
 #include <stdio.h>  /* NULL, printf() */
 #include <string.h> /* strlen() */
@@ -278,6 +260,7 @@ void window_fs_mkdir(s3dw_widget *button)
 			/*   parse_again(item);*/
 		}
 	}
+	free(dir);
 	fs_lock = 0;
 	window_fs_abort(button); /* finish */
 
@@ -330,14 +313,14 @@ void window_info(char *path)
 	s3dw_surface *infwin;
 	s3dw_button  *button;
 	char string1[M_DIR];
-	char string2[M_DIR];
+	char string2[567];
 	int b, d, f;
 	char bd[M_DIR];
 	float l;
 	snprintf(string1, M_DIR, "Info for %s", path);
 	fs_approx(path, &f, &d, &b);
 	dotted_int(bd, b);
-	snprintf(string2 , M_DIR, "%s bytes in %d files and %d Directories", bd, f, d);
+	snprintf(string2, sizeof(string2), "%s bytes in %d files and %d Directories", bd, f, d);
 
 	l = ((strlen(string1) > strlen(string2)) ? strlen(string1) : strlen(string2)) * 0.7;
 
