@@ -1,29 +1,13 @@
-/*
- * fly.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dfm, a s3d file manager.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dfm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dfm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dfm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #include "s3dfm.h"
+#include <s3d.h> /* NULL */
 #include <stdio.h> /* NULL */
 #include <string.h> /* strncpy() */
+#include <stdlib.h> /* malloc() */
+#include <string.h> /* strncpy() */
 static void _get_pos(t_node *work, t_node *f)
 {
 	if (f->parent != NULL) _get_pos(work, f->parent);
@@ -66,7 +50,7 @@ t_node *fly_create_anode(t_node *node)
 	work->py = node->py;
 	work->pz = node->pz;
 	work->type = node->type;
-	strncpy(work->name, node->name, M_NAME);
+	mstrncpy(work->name, node->name, M_NAME);
 	fly_set_absolute_position(work);
 	icon_draw(work);
 
