@@ -1,24 +1,5 @@
-/*
- * node.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dfm, a s3d file manager.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dfm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dfm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dfm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #include "s3dfm.h"
@@ -35,7 +16,7 @@ t_node *node_getbypath(const char *path)
 
 	if (path == NULL) return NULL;
 	if (path[0] == '/') {
-		strncpy(p, path, M_DIR - 1);
+		mstrncpy(p, path, M_DIR - 1);
 		s = p + 1;
 		cur = &root;
 	} else return NULL; /* TODO: also process local paths. right now, we are to lazy */
@@ -155,8 +136,10 @@ int node_delete(t_node *dir)
 	switch (dir->disp) {
 	case D_DIR:
 		box_undisplay(dir);
+		/* fall through */
 	case D_ICON:
 		icon_undisplay(dir);
+		/* fall through */
 	}
 
 	if (-1 != (i = ani_onstack(dir))) ani_del(i); /* tell animation stack too */
