@@ -1,24 +1,5 @@
-/*
- * draw.c
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dosm, a gps card application for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dosm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dosm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dosm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 #include "s3dosm.h"
 #include <s3d.h>
@@ -178,16 +159,22 @@ static void waylist_draw(const char *filter)
 	switch (waytype) {
 	case 5:
 		s3d_push_material(way_obj, 0.2, 0.2, 0.6,  1.0, 1.0, 1.0, 0.3, 0.3, 1.0); /* motorway */
+		break;
 	case 4:
 		s3d_push_material(way_obj, 0.3, 0.3, 0.4,  1.0, 1.0, 1.0, 0.5, 0.5, 0.8); /* motorway_link*/
+		break;
 	case 3:
 		s3d_push_material(way_obj, 0.6, 0.3, 0.1,  1.0, 1.0, 1.0,  1.0, 0.6, 0.2); /* primary */
+		break;
 	case 2:
 		s3d_push_material(way_obj, 0.6, 0.6, 0.0,  1.0, 1.0, 1.0,  1.0, 1.0, 0.0); /* secondary */
+		break;
 	case 1:
 		s3d_push_material(way_obj, 0.6, 0.6, 0.6,  1.0, 1.0, 1.0,  1.0, 1.0, 1.0); /* residential */
+		break;
 	default:
 		s3d_push_material(way_obj, 0.6, 0.2, 0.6,  1.0, 1.0, 1.0, 1.0, 0.5, 1.0); /* default */
+		break;
 	}
 	street_width = (0.5 + waytype / 10) / RESCALE;
 	/* put nodes of the graph into a list */
@@ -364,9 +351,9 @@ static void waylist_add(struct waylist *p)
 {
 	if (waylist_n >= waylist_bufn) {
 		waylist_bufn += 64;
-		waylist_p = (struct waylist *)realloc(waylist_p, sizeof(struct waylist) * waylist_bufn);
-		nodelist_p = (struct nodelist *)realloc(nodelist_p, sizeof(struct nodelist) * waylist_bufn * 2); /* we can have twice as many nodes as there are segments in a graph. */
-		adjlist_p = (struct adjlist *)realloc(adjlist_p, sizeof(struct nodelist) * waylist_bufn * 2);
+		waylist_p = realloc(waylist_p, sizeof(*waylist_p) * waylist_bufn);
+		nodelist_p = realloc(nodelist_p, sizeof(*nodelist_p) * waylist_bufn * 2); /* we can have twice as many nodes as there are segments in a graph. */
+		adjlist_p = realloc(adjlist_p, sizeof(*adjlist_p) * waylist_bufn * 2);
 	}
 	waylist_p[waylist_n].node_to = p->node_to;
 	waylist_p[waylist_n].node_from = p->node_from;
