@@ -1,27 +1,9 @@
-/* http_fetcher.c - HTTP handling functions
- *
- * Copyright (C) 2001  Lyle Hanson <lhanson@cs.nmu.edu>
- *
- * This file is part of s3dosm, a gps card application for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dosm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dosm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dosm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2001  Lyle Hanson <lhanson@cs.nmu.edu>
  *
  *
  * Changes:
- *  Simon Wunderlich <dotslash@packetmixer.de>
+ *  Simon Wunderlich <sw@simonwunderlich.de>
  *  + added http_setAuth() to support basic http-authentication and some minor fixes
  */
 
@@ -35,6 +17,7 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include "http_fetcher.h"
+#include "http_error_codes.h"
 
 /* Globals */
 static int timeout = DEFAULT_READ_TIMEOUT;
@@ -75,12 +58,11 @@ int http_fetch(const char *url_tmp, char **fileBuf)
 	}
 
 	/* Copy the url passed in into a buffer we can work with, change, etc. */
-	url = (char*)malloc(strlen(url_tmp) + 1);
-	if (url == NULL) {
+	url = strdup(url_tmp);
+	if (!url) {
 		errorSource = ERRNO;
 		return -1;
 	}
-	strncpy(url, url_tmp, strlen(url_tmp) + 1);
 
 	/* Seek to the file path portion of the url */
 	charIndex = strstr(url, "://");
@@ -105,34 +87,51 @@ int http_fetch(const char *url_tmp, char **fileBuf)
 	if (charIndex != NULL)
 		*charIndex = 0;
 
-	strcat(requestBuf, "Host: ");
-	strcat(requestBuf, host);
-	strcat(requestBuf, "\r\n");
+	strncat(requestBuf, "Host: ",
+		sizeof(requestBuf) - 1 - strlen(requestBuf));
+	strncat(requestBuf, host, sizeof(requestBuf) - 1 - strlen(requestBuf));
+	strncat(requestBuf, "\r\n",
+		sizeof(requestBuf) - 1 - strlen(requestBuf));
 
 
 	if (!hideReferer && referer != NULL) { /* NO default referer */
-		strcat(requestBuf, "Referer: ");
-		strcat(requestBuf, referer);
-		strcat(requestBuf, "\r\n");
+		strncat(requestBuf, "Referer: ",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, referer,
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, "\r\n",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
 	}
 
 	if (!hideUserAgent && userAgent == NULL) {
-		strcat(requestBuf, "User-Agent: ");
-		strcat(requestBuf, DEFAULT_USER_AGENT);
-		strcat(requestBuf, "/");
-		strcat(requestBuf, HTTP_FETCHER_VERSION);
-		strcat(requestBuf, "\r\n");
+		strncat(requestBuf, "User-Agent: ",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, DEFAULT_USER_AGENT,
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, "/",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, HTTP_FETCHER_VERSION,
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, "\r\n",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
 	} else if (!hideUserAgent) {
-		strcat(requestBuf, "User-Agent: ");
-		strcat(requestBuf, userAgent);
-		strcat(requestBuf, "\r\n");
+		strncat(requestBuf, "User-Agent: ",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, userAgent,
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, "\r\n",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
 	}
 	if (auth != NULL) {
-		strcat(requestBuf, "Authorization: Basic ");
-		strcat(requestBuf, auth);
-		strcat(requestBuf, "\r\n");
+		strncat(requestBuf, "Authorization: Basic ",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, auth,
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
+		strncat(requestBuf, "\r\n",
+			sizeof(requestBuf) - 1 - strlen(requestBuf));
 	}
-	strcat(requestBuf, "\r\n");
+	strncat(requestBuf, "\r\n",
+		sizeof(requestBuf) - 1 - strlen(requestBuf));
 
 	printf("[HTTP] creating connection ...\n");
 	sock = makeSocket(host);   /* errorSource set within makeSocket */
@@ -314,20 +313,23 @@ int http_fetch(const char *url_tmp, char **fileBuf)
 int http_setUserAgent(const char *newAgent)
 {
 	char *tmp;
+	size_t agent_len;
 
 	if (newAgent == NULL) {
 		if (freeOldAgent) free(userAgent);
 		userAgent = NULL;
 		hideUserAgent = 1;
 	} else {
-		tmp = (char *)malloc(strlen(newAgent));
+		agent_len = strlen(newAgent) + 1;
+		tmp = (char *)malloc(agent_len);
 		if (tmp == NULL) {
 			errorSource = ERRNO;
 			return -1;
 		}
 		if (freeOldAgent) free(userAgent);
 		userAgent = tmp;
-		strcpy(userAgent, newAgent);
+		strncpy(userAgent, newAgent, agent_len);
+		userAgent[agent_len - 1] = '\0';
 		freeOldAgent = 1;
 		hideUserAgent = 0;
 	}
@@ -343,20 +345,23 @@ int http_setUserAgent(const char *newAgent)
 int http_setReferer(const char *newReferer)
 {
 	char *tmp;
+	size_t referer_len;
 
 	if (newReferer == NULL) {
 		if (freeOldReferer) free(referer);
 		referer = NULL;
 		hideReferer = 1;
 	} else {
-		tmp = (char *)malloc(strlen(newReferer));
+		referer_len = strlen(newReferer) + 1;
+		tmp = (char *)malloc(referer_len);
 		if (tmp == NULL) {
 			errorSource = ERRNO;
 			return -1;
 		}
 		if (freeOldReferer) free(referer);
 		referer = tmp;
-		strcpy(referer, newReferer);
+		strncpy(referer, newReferer, referer_len);
+		referer[referer_len - 1] = '\0';
 		freeOldReferer = 1;
 		hideReferer = 0;
 	}
@@ -436,6 +441,7 @@ void http_setTimeout(int seconds)
 int http_parseFilename(const char *url, char **filename)
 {
 	char *ptr;
+	size_t ptr_len;
 
 	if (url == NULL) {
 		errorSource = FETCHER_ERROR;
@@ -451,12 +457,14 @@ int http_parseFilename(const char *url, char **filename)
 	ptr++;
 	if (*ptr == '\0') return 1;
 
-	*filename = (char *)malloc(strlen(ptr));
+	ptr_len = strlen(ptr) + 1;
+	*filename = (char *)malloc(ptr_len);
 	if (*filename == NULL) {
 		errorSource = ERRNO;
 		return -1;
 	}
-	strcpy(*filename, ptr);
+	strncpy(*filename, ptr, ptr_len);
+	*filename[ptr_len - 1] = '\0';
 
 	return 0;
 }
@@ -526,7 +534,8 @@ const char *http_strerror(void)
 			        abs(stringIndex - originalError));
 			sprintf(&convertedError[strlen(convertedError)], "%d", errorInt);
 			stringIndex += 2;  /* Skip past the %d */
-			strcat(convertedError, stringIndex);
+			strncat(convertedError, stringIndex,
+				sizeof(convertedError) - 1 - strlen(convertedError));
 
 			return convertedError;
 		}
@@ -618,6 +627,7 @@ int makeSocket(const char *host)
 	}
 
 	/* Copy host address from hostent to (server) socket address */
+	memset(&sa, 0, sizeof(sa));
 	memcpy((char *)&sa.sin_addr, (char *)hp->h_addr, hp->h_length);
 	sa.sin_family = hp->h_addrtype;  /* Set service sin_family to PF_INET */
 	sa.sin_port = htons(PORT_NUMBER); /* Put portnum into sockaddr */
@@ -628,8 +638,9 @@ int makeSocket(const char *host)
 		return -1;
 	}
 
-	ret = connect(sock, (struct sockaddr *) & sa, sizeof(sa));
+	ret = connect(sock, (struct sockaddr *)&sa, sizeof(sa));
 	if (ret == -1) {
+		close(sock);
 		errorSource = ERRNO;
 		return -1;
 	}
