@@ -1,36 +1,14 @@
-/* http_fetcher.h - HTTP handling functions
- *
- * HTTP Fetcher
- * Copyright (C) 2001  Lyle Hanson <lhanson@cs.nmu.edu>
- *
- * This file is part of s3dosm, a gps card application for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dosm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dosm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dosm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+/* SPDX-License-Identifier: GPL-2.0-or-later */
+/* SPDX-FileCopyrightText: 2001  Lyle Hanson <lhanson@cs.nmu.edu>
  *
  * Changes:
- *  Simon Wunderlich <dotslash@packetmixer.de>
+ *  Simon Wunderlich <sw@simonwunderlich.de>
  *  + added http_setAuth() to support basic http-authentication and some minor fixes
  */
 
 #ifndef HTTP_FETCHER_H
 #define HTTP_FETCHER_H
 
-#include "http_error_codes.h"
-
 #define PORT_NUMBER    80
 #define HTTP_VERSION    "HTTP/1.1"
 #define DEFAULT_USER_AGENT  "HTTP Fetcher"
