@@ -1,32 +1,23 @@
-/*
- * s3dosm.h
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dosm, a gps card application for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dosm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dosm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dosm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+/* SPDX-License-Identifier: GPL-2.0-or-later */
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #ifndef _S3DOSM_H_
 #define _S3DOSM_H_
 
-#include <sqlite3.h>
-#include <s3d.h> /* s3devt structure */
-#include <config-s3d.h>
+#include <config-s3d.h>              /* for UNUSEDPARAM_ATTRIBUTE */
+#include <sqlite3.h>                 /* for sqlite3_callback */
+struct _adj_t;
+struct _icon_t;
+struct _layer_t;
+struct _layerset_t;
+struct _node_t;
+struct _object_t;
+struct _segment_t;
+struct _tag_t;
+struct _way_t;
+struct s3d_evt;
+
 #define ESIZE 637800  /* earth size */
 #define RESCALE 1
 #define VIEWHEIGHT 3
@@ -169,7 +160,7 @@ void mainloop(void);
 void debug_obj(object_t *obj, void *dummy);
 layer_t *parse_osm(const char *buf, int length);
 layer_t *load_osm_file(const char *filename);
-layer_t *load_osm_web(float minlon, float minlat, float maxlon, float maxlat);
+layer_t *load_osm_web(float minlat, float minlon, float maxlat, float maxlon);
 /* kismet.c */
 layer_t *parse_kismet(const char *buf, int length);
 layer_t *load_kismet_file(const char *filename);
