@@ -1,24 +1,5 @@
-/*
- * ui.c
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3dosm, a gps card application for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3dosm is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3dosm is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3dosm; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #include <s3d.h>
@@ -56,7 +37,7 @@ static int ui_getinfo_node(void *S3DOSMUNUSED(data), int argc, char **argv, char
 	int i, tagid = -1;
 	char type[MAXQ];
 	char name[MAXQ];
-	char string[128];
+	char string[4102];
 	s3dw_surface *miniwin;
 	s3dw_button  *button;
 
@@ -69,9 +50,9 @@ static int ui_getinfo_node(void *S3DOSMUNUSED(data), int argc, char **argv, char
 	if (db_gettag(tagid, "name", name)) name[0] = 0;
 
 	miniwin = s3dw_surface_new("About node", 30, 6);
-	snprintf(string, 128, "name: %s", name);
+	snprintf(string, sizeof(string), "name: %s", name);
 	s3dw_label_new(miniwin, string, 1, 2);
-	snprintf(string, 128, "type: %s", type);
+	snprintf(string, sizeof(string), "type: %s", type);
 	s3dw_label_new(miniwin, string, 1, 4);
 	button = s3dw_button_new(miniwin, "OK", 2, 6);
 	button->onclick = key_button;
@@ -83,7 +64,7 @@ static int ui_getinfo_way(void *S3DOSMUNUSED(data), int argc, char **argv, char
 {
 	int i, tagid = -1;
 	char name[MAXQ];
-	char string[128];
+	char string[4102];
 	s3dw_surface *miniwin;
 	s3dw_button  *button;
 
@@ -96,7 +77,7 @@ static int ui_getinfo_way(void *S3DOSMUNUSED(data), int argc, char **argv, char
 	printf("reporting street %s\n", name);
 
 	miniwin = s3dw_surface_new("About street", 30, 6);
-	snprintf(string, 128, "name: %s", name);
+	snprintf(string, sizeof(string), "name: %s", name);
 	s3dw_label_new(miniwin, string, 1, 2);
 	button = s3dw_button_new(miniwin, "OK", 2, 4);
 	button->onclick = key_button;
