@@ -1,24 +1,5 @@
-/*
- * s3dclock.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3d, a 3d network display server.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
@@ -36,9 +17,10 @@ static struct tm *mytime;
 static time_t now, onow;
 static char time_str[256];
 
-static void stop(struct s3d_evt *S3DUNUSED(evt))
+static int stop(struct s3d_evt *S3DUNUSED(evt))
 {
 	s3d_quit();
+	return 0;
 }
 
 static void mainloop(void)
