@@ -1,29 +1,13 @@
-/*
- * callback.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d API, the API of s3d (the 3d network display server).
- * See http://s3d.berlios.de/ for more updates.
- *
- * The s3d API is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * The s3d API is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d API; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: LGPL-2.1-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
-#include "s3d.h"
-#include "s3dlib.h"
+#include <stddef.h>                  /* for NULL */
+#include <stdint.h>                  /* for uint8_t */
+#include "s3d.h"                     /* for s3d_cb, s3d_process_stack */
+#include "s3dlib.h"                  /* for MAX_CB, S3DUNUSED */
+
 static int _s3d_ignore(struct s3d_evt *evt);
 /*  the s3d callback list */
 /* i know it's ugly, but it's better to have ugly code somewhere than provoke
