@@ -1,31 +1,12 @@
-/*
- * event.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d API, the API of s3d (the 3d network display server).
- * See http://s3d.berlios.de/ for more updates.
- *
- * The s3d API is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * The s3d API is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d API; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: LGPL-2.1-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
-#include "s3d.h"
-#include "s3dlib.h"
-#include "proto.h"
-#include <stdlib.h>   /*  malloc(), free() */
+#include <stdint.h>                  /* for uint8_t */
+#include <stdlib.h>                  /* for NULL, free */
+#include "s3d.h"                     /* for s3d_evt, s3d_get_callback, etc */
+#include "s3dlib.h"                  /* for s3dprintf, VLOW, etc */
 
 static struct s3d_evt *s3d_stack;
 int cb_lock = 2;  /*  callback lock */
@@ -99,10 +80,12 @@ struct s3d_evt *s3d_find_event(uint8_t event) {
 int s3d_delete_event(const struct s3d_evt *devt)
 {
 	struct s3d_evt *previous = NULL;
+	struct s3d_evt *next;
 	struct s3d_evt *p = s3d_stack;
 	while (p != NULL) {
 		/* if ((p->event==devt->event) && (p->length==devt->length)) */
 		/*  if (0==memcmp(p->buf,devt->buf)) */
+		next = p->next;
 		if (p == devt) {
 			if (p->length > 0)
 				free(p->buf);
@@ -110,10 +93,12 @@ int s3d_delete_event(const struct s3d_evt *devt)
 				s3d_stack = p->next;  /*  the first element!! */
 			else
 				previous->next = p->next;  /*  unlink */
+
 			free(p);
+		} else {
+			previous = p;
 		}
-		previous = p;
-		p = p->next;
+		p = next;
 	}
 	return -1;
 }
