@@ -1,24 +1,5 @@
-/*
- * freetype.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d API, the API of s3d (the 3d network display server).
- * See http://s3d.berlios.de/ for more updates.
- *
- * The s3d API is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * The s3d API is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d API; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: LGPL-2.1-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
@@ -175,7 +156,7 @@ static int _s3d_add_tessbuf(uint16_t a)
 			outl = -1;
 			/* find an outline */
 			for (i = 0; i < n; i++)
-				if (area[perm[i]] > 0) {
+				if (area[perm[i]] >= 0) {
 					outl = i; /* found. that was easy ;) */
 					break;
 				}
@@ -335,7 +316,8 @@ int s3d_select_font(const char *path)
 		if ((memory_font_size = s3d_open_file(c, p)) > 0) {
 			if (!s3d_ft_load_font()) { /* success */
 				if (oldfont != NULL)    free(oldfont);
-				strncpy(oldfontpath, path, 256);
+				strncpy(oldfontpath, path, sizeof(oldfontpath));
+				oldfontpath[sizeof(oldfontpath) - 1] = '\0';
 				return 0;
 			} else {
 				memory_font = oldfont;
