@@ -1,25 +1,6 @@
-/*
- * s3d.h
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>,
- * Copyright (C) 2004-2011  Sven Eckelmann <sven@narfation.org>
- *
- * This file is part of the s3d API, the API of s3d (the 3d network display server).
- * See http://s3d.berlios.de/ for more updates.
- *
- * The s3d API is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * The s3d API is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d API; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>,
+ * SPDX-FileCopyrightText: 2004-2015  Sven Eckelmann <sven@narfation.org>
  */
 
 
@@ -42,11 +23,9 @@
 
 #ifdef __GNUC_MINOR__
 #define S3D_WARN_UNUSED_RESULT  __attribute__ ((warn_unused_result))
-#define S3D_CONST  __attribute__ ((const))
 #define S3D_PURE  __attribute__ ((pure))
 #else
 #define S3D_WARN_UNUSED_RESULT
-#define S3D_CONST
 #define S3D_PURE
 #endif
 
@@ -227,12 +206,12 @@ extern "C"
 
 	/* some vector calculation helpers */
 
-	S3DEXPORT float s3d_vector_length(const float vector[]) S3D_CONST;
-	S3DEXPORT float s3d_vector_dot_product(const float vector1[], const float vector2[]) S3D_CONST;
-	S3DEXPORT void s3d_vector_subtract(const float vector1[], const float vector2[], float result_vector[]) S3D_CONST;
-	S3DEXPORT float s3d_vector_angle(const float vector1[], const float vector2[]) S3D_CONST;
-	S3DEXPORT float s3d_angle_to_cam(const float obj_pos[], const float cam_pos[], float *angle_rad) S3D_CONST;
-	S3DEXPORT void s3d_vector_cross_product(const float vector1[], const float vector2[], float result_vector[]) S3D_CONST;
+	S3DEXPORT float s3d_vector_length(const float vector[]) S3D_PURE;
+	S3DEXPORT float s3d_vector_dot_product(const float vector1[], const float vector2[]) S3D_PURE;
+	S3DEXPORT void s3d_vector_subtract(const float vector1[], const float vector2[], float result_vector[]);
+	S3DEXPORT float s3d_vector_angle(const float vector1[], const float vector2[]) S3D_PURE;
+	S3DEXPORT float s3d_angle_to_cam(const float obj_pos[], const float cam_pos[], float *angle_rad);
+	S3DEXPORT void s3d_vector_cross_product(const float vector1[], const float vector2[], float result_vector[]);
 
 	/* event handlers */
 	S3DEXPORT void s3d_push_event(struct s3d_evt *newevt);
