@@ -1,8 +1,6 @@
-/*
- * sei_triangulate.h
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- * Copyright (C) 1994  A. Narkhede and D .Manocha, who released their code
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
+ * SPDX-FileCopyrightText: 1994  A. Narkhede and D .Manocha, who released their code
  * for public domain:
  * <snip>
  *
@@ -17,34 +15,13 @@
  *
  *                                 - Atul Narkhede (narkhede@cs.unc.edu)
  * </snip>
- *
- * This file is part of the s3d API, the API of s3d (the 3d network display server).
- * See http://s3d.berlios.de/ for more updates.
- *
- * The s3d API is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * The s3d API is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d API; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 
 #ifndef _triangulate_h
 #define _triangulate_h
 
-#include <sys/types.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include "s3d.h"
-#include "s3dlib.h"
+#include "config.h"
 
 typedef struct {
 	double x, y;
