@@ -1,29 +1,11 @@
-/*
- * input.c
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d Widgets, a Widget Library for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d Widgets is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * s3d Widgets is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d Widgets; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: LGPL-2.1-or-later
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 
 #include <s3d.h>
 #include <s3d_keysym.h>
+#include <s3dlib.h>
 #include <s3dw.h>
 #include <s3dw_int.h>
 #include <stdlib.h> /* malloc() */
@@ -211,7 +193,7 @@ int s3dw_input_event_key(s3dw_widget *widget, struct s3d_key_event *keys)
 	case S3DK_BACKSPACE:
 		if ((len = strlen(input->text)) > 0) {
 			newtext = (char *)malloc(len + 0); /* +1 for the terminating byte, -1 for the deleted character */
-			strncpy(newtext, input->text, len);
+			memcpy(newtext, input->text, len);
 			newtext[len-1] = 0;
 			s3dw_input_change_text(input, newtext);
 			free(newtext);
