@@ -1,32 +1,20 @@
-/*
- * s3dw.h
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d Widgets, a Widget Library for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d Widgets is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * s3d Widgets is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d Widgets; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #ifndef LIBS3DW_H
 #define LIBS3DW_H
-#ifndef LIBS3D_H
-#include <s3d.h>
-#endif
-#include <stdint.h>  /* [u]intXX_t type definitions*/
+
+#include <stdint.h>                  /* for uint32_t */
+struct _s3dw_button;
+struct _s3dw_input;
+struct _s3dw_label;
+struct _s3dw_scrollbar;
+struct _s3dw_style;
+struct _s3dw_surface;
+struct _s3dw_textbox;
+struct _s3dw_widget;
+struct s3d_evt;
 
 #ifdef HAVE_GCCVISIBILITY
 #define S3DWEXPORT_VISIBILITY __attribute__ ((visibility("default")))
