@@ -1,30 +1,13 @@
-/*
- * s3dw_int.h
- *
- * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of the s3d Widgets, a Widget Library for s3d.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d Widgets is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * s3d Widgets is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with the s3d Widgets; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
+/* SPDX-FileCopyrightText: 2006-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #ifndef LIBS3DW_INT_H
 #define LIBS3DW_INT_H
 
-#include <s3dlib.h> /* s3dprintf() */
+#include <s3dw.h>                    /* for s3dw_widget, ::S3DW_NTYPES, etc */
+#include <stdint.h>                  /* for uint32_t */
+
 #define MAXANI  128
 #define ZOOMS  5
 /* constructor and handler callbacks */
@@ -45,7 +28,7 @@ void s3dw_root_destroy(s3dw_widget *widget);
 const char *s3dw_get_type_string(int type);
 /* widget.c */
 s3dw_widget* s3dw_widget_new(s3dw_widget *widget);
-void s3dw_widget_append(s3dw_widget *parent, s3dw_widget *widget);
+int s3dw_widget_append(s3dw_widget *parent, s3dw_widget *widget);
 void s3dw_widget_visible(s3dw_widget *widget);
 int s3dw_widget_event_click(s3dw_widget *widget, uint32_t oid);
 int s3dw_widget_event_key(s3dw_widget *widget, struct s3d_key_event *keys);
