@@ -1,29 +1,11 @@
-/*
- * process.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3d, a 3d network display server.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #include "global.h"
 #include <stdlib.h>		/*  for malloc, free */
 #include <string.h>		/*  strncmp(), strncpy() */
+#include <errno.h>
 /*  this piece of code handles processes */
 
 #define mcp_p (&procs_p[0])
@@ -64,7 +46,8 @@ struct t_process *process_protinit(struct t_process *p, const char *name)
 			return NULL;
 		}
 	} else {
-		strncpy(p->name, name, S3D_NAME_MAX);
+		strncpy(p->name, name, sizeof(p->name));
+		p->name[sizeof(p->name) - 1] = '\0';
 		process_sys_init(p);
 
 		/* register the new process in the mcp */
@@ -229,7 +212,11 @@ int process_init(void)
 	procs_p = NULL;
 	process_add();
 	/* set up mcp */
-	strncpy(mcp_p->name, "mcp", S3D_NAME_MAX);
+	if (!mcp_p)
+		return -ENOMEM;
+
+	strncpy(mcp_p->name, "mcp", sizeof(mcp_p->name));
+	mcp_p->name[sizeof(mcp_p->name) - 1] = '\0';
 	mcp_p->con_type = CON_NULL;
 	process_sys_init(mcp_p);
 	return 0;
