@@ -1,24 +1,5 @@
-/*
- * user_sdl.c
- *
- * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
- *
- * This file is part of s3d, a 3d network display server.
- * See http://s3d.berlios.de/ for more updates.
- *
- * s3d is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * s3d is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with s3d; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+// SPDX-License-Identifier: GPL-2.0-or-later
+/* SPDX-FileCopyrightText: 2004-2015  Simon Wunderlich <sw@simonwunderlich.de>
  */
 
 #include "global.h"
@@ -28,13 +9,18 @@
 
 int user_init_sdl(void)
 {
+#if SDL_VERSION_ATLEAST(2,0,0)
+#else
 	SDL_EnableUNICODE(1);
+#endif
 	return 0;
 }
 
 int user_main_sdl(void)
 {
 	SDL_Event event;
+	uint32_t unicode = 0;
+
 	while (SDL_PollEvent(&event)) {
 		switch (event.type) {
 		case SDL_MOUSEMOTION:
@@ -70,12 +56,14 @@ int user_main_sdl(void)
 			case SDL_BUTTON_RIGHT:
 				user_mouse(2, 0, event.motion.x, event.motion.y);
 				break;
+#if !SDL_VERSION_ATLEAST(2,0,0)
 			case SDL_BUTTON_WHEELUP:
 				user_mouse(3, 0, event.motion.x, event.motion.y);
 				break;
 			case SDL_BUTTON_WHEELDOWN:
 				user_mouse(4, 0, event.motion.x, event.motion.y);
 				break;
+#endif
 			default:
 				s3dprintf(LOW, "don't know button %d", event.button.button);
 			}
@@ -91,34 +79,73 @@ int user_main_sdl(void)
 			case SDL_BUTTON_RIGHT:
 				user_mouse(2, 1, event.motion.x, event.motion.y);
 				break;
+#if !SDL_VERSION_ATLEAST(2,0,0)
 			case SDL_BUTTON_WHEELUP:
 				user_mouse(3, 1, event.motion.x, event.motion.y);
 				break;
 			case SDL_BUTTON_WHEELDOWN:
 				user_mouse(4, 1, event.motion.x, event.motion.y);
 				break;
+#endif
 			default:
 				s3dprintf(LOW, "don't know button %d", event.button.button);
 			}
 			break;
 
-		case SDL_KEYDOWN:
-			user_key(event.key.keysym.sym, event.key.keysym.unicode, event.key.keysym.mod, 0);
+#if SDL_VERSION_ATLEAST(2,0,0)
+		case SDL_MOUSEWHEEL:
+			if (event.wheel.y > 0) {
+				user_mouse(3, 0, event.motion.x, event.motion.y);
+				user_mouse(3, 1, event.motion.x, event.motion.y);
+			}
+			if (event.wheel.y < 0) {
+				user_mouse(4, 0, event.motion.x, event.motion.y);
+				user_mouse(4, 1, event.motion.x, event.motion.y);
+			}
 			break;
+#endif
+
+		case SDL_KEYDOWN:
 		case SDL_KEYUP:
-			user_key(event.key.keysym.sym, event.key.keysym.unicode, event.key.keysym.mod, 1);
+			unicode = 0;
+#if SDL_VERSION_ATLEAST(2,0,0)
+			if (event.key.keysym.sym < 256) {
+				unicode = event.key.keysym.sym;
+				if (unicode >= 'a' && unicode <= 'z') {
+					int shifted = !!(event.key.keysym.mod & KMOD_SHIFT);
+					int capslock = !!(event.key.keysym.mod & KMOD_CAPS);
+					if ((shifted ^ capslock) != 0) {
+						unicode = SDL_toupper(unicode);
+					}
+				}
+			}
+#else
+			unicode = event.key.keysym.unicode;
+#endif
+			user_key(event.key.keysym.sym, unicode, event.key.keysym.mod, (event.type == SDL_KEYUP) ? 1 : 0);
 			break;
 		case SDL_QUIT:
 			s3dprintf(HIGH, "SDL_QUIT");
 			quit();
 			break;
 			/*  these events are not processed right now ... */
+#if !SDL_VERSION_ATLEAST(2,0,0)
 		case SDL_ACTIVEEVENT:
 			s3dprintf(VLOW, "SDL_ACTIVEEVENT");
 			break;
+#endif
 		case SDL_SYSWMEVENT:
 			s3dprintf(VLOW, "SDL_SYSWMEVENT");
 			break;
+#if SDL_VERSION_ATLEAST(2,0,0)
+		case SDL_WINDOWEVENT:
+			switch (event.window.event) {
+				case SDL_WINDOWEVENT_RESIZED:
+					graphics_reshape(event.window.data1, event.window.data2);
+					break;
+			}
+			break;
+#else
 		case SDL_VIDEORESIZE:
 			if (SDL_SetVideoMode(event.resize.w, event.resize.h, 16, SDLFlags) == NULL)
 				errsf("SDL_SetVideoMode()", SDL_GetError());
@@ -127,6 +154,7 @@ int user_main_sdl(void)
 		case SDL_VIDEOEXPOSE:
 			s3dprintf(VLOW, "SDL_VIDEOEXPOSE");
 			break;
+#endif
 		case SDL_USEREVENT:
 			s3dprintf(VLOW, "SDL_USEREVENT");
 			break;
